@@ -168,11 +168,40 @@ MIGRATION_SCRIPT
     rm -f /tmp/whp-apply-migrations.sh
 fi
 
-# Sync files (excluding sql/migrations since we already applied them)
+# Apply shell scripts after SQL migrations
+if [ -d "$SCRIPT_DIR/scripts/updates" ]; then
+    echo ""
+    echo "Applying update scripts..."
+    
+    # Use the apply-scripts.sh from the current installation, not the new version
+    if [ -f "/root/whp/scripts/apply-scripts.sh" ]; then
+        chmod +x "/root/whp/scripts/apply-scripts.sh"
+        "/root/whp/scripts/apply-scripts.sh" "$CURRENT_VERSION" "$NEW_VERSION" "$SCRIPT_DIR/scripts/updates"
+        
+        if [ $? -ne 0 ]; then
+            echo -e "${RED}Error applying update scripts. Update aborted.${NC}"
+            exit 1
+        fi
+    elif [ -f "$SCRIPT_DIR/scripts/apply-scripts.sh" ]; then
+        # Fallback to new version if current doesn't exist (first time setup)
+        chmod +x "$SCRIPT_DIR/scripts/apply-scripts.sh"
+        "$SCRIPT_DIR/scripts/apply-scripts.sh" "$CURRENT_VERSION" "$NEW_VERSION" "$SCRIPT_DIR/scripts/updates"
+        
+        if [ $? -ne 0 ]; then
+            echo -e "${RED}Error applying update scripts. Update aborted.${NC}"
+            exit 1
+        fi
+    else
+        echo -e "${YELLOW}No apply-scripts.sh found, skipping script execution${NC}"
+    fi
+fi
+
+# Sync files (excluding sql/migrations and scripts/updates since we already applied them)
 echo ""
 echo "Syncing files to /root/whp..."
 rsync -av \
   --exclude='sql/migrations/' \
+  --exclude='scripts/updates/' \
   --exclude='update.sh' \
   "$SCRIPT_DIR/" /root/whp/
 
