@@ -390,6 +390,26 @@ class MailServerClient {
         return $this->makeRequest('PATCH', "boxes/$encoded_email/quota", $quota_data);
     }
     
+    /**
+     * Get email accounts from mail server with optional domain filter
+     * @param string $domain Domain to filter by (optional)
+     * @param int $page Page number (default 1)
+     * @param int $paging Number of results per page (default 500)
+     * @return array Response from mail server API
+     */
+    public function getEmailAccounts($domain = null, $page = 1, $paging = 500) {
+        $params = [
+            'page' => $page,
+            'paging' => $paging
+        ];
+        
+        if ($domain) {
+            $params['query'] = $domain;
+        }
+        
+        $query = http_build_query($params);
+        return $this->makeRequest('GET', "boxes?$query");
+    }
 
     
     /**
