@@ -647,6 +647,9 @@ $stats = [
 </div>
 
 <script>
+// Define CSRF token for AJAX requests
+const nonce = '<?php echo get_csrf_token(); ?>';
+
 // Show/hide selection fields based on backup type
 document.getElementById('backupType').addEventListener('change', function() {
     const siteSelect = document.getElementById('siteSelect');
@@ -670,7 +673,7 @@ document.getElementById('backupForm').addEventListener('submit', function(e) {
     formData.append('action', 'create_backup');
     formData.append('backup_type', document.getElementById('backupType').value);
     formData.append('target_id', document.getElementById('targetSelection').value);
-    formData.append('nonce', '<?php echo $_SESSION['nonce']; ?>');
+    // CSRF token will be added via header
     
     <?php if ($isRoot): ?>
     if (document.getElementById('backupUser')) {
@@ -686,6 +689,9 @@ document.getElementById('backupForm').addEventListener('submit', function(e) {
     
     fetch('api/backup-actions.php', {
         method: 'POST',
+        headers: {
+            'X-CSRF-Token': nonce
+        },
         body: formData
     })
     .then(response => response.json())
@@ -708,10 +714,13 @@ document.getElementById('targetForm').addEventListener('submit', function(e) {
     
     const formData = new FormData(this);
     formData.append('action', document.getElementById('targetId').value ? 'update_target' : 'create_target');
-    formData.append('nonce', '<?php echo $_SESSION['nonce']; ?>');
+    // CSRF token will be added via header
     
     fetch('api/backup-actions.php', {
         method: 'POST',
+        headers: {
+            'X-CSRF-Token': nonce
+        },
         body: formData
     })
     .then(response => response.json())
@@ -749,7 +758,7 @@ function testTarget(targetId) {
 }
 
 function downloadBackup(backupId) {
-    window.location.href = 'api/backup-actions.php?action=download&backup_id=' + backupId + '&nonce=<?php echo $_SESSION['nonce']; ?>';
+    window.location.href = 'api/backup-actions.php?action=download&backup_id=' + backupId + '&csrf_token=<?php echo get_csrf_token(); ?>';
 }
 
 function deleteBackup(backupId) {
@@ -758,8 +767,9 @@ function deleteBackup(backupId) {
             method: 'POST',
             headers: {
                 'Content-Type': 'application/x-www-form-urlencoded',
+                'X-CSRF-Token': nonce
             },
-            body: `action=delete_backup&backup_id=${backupId}&nonce=<?php echo $_SESSION['nonce']; ?>`
+            body: `action=delete_backup&backup_id=${backupId}`
         })
         .then(response => response.json())
         .then(data => {
@@ -818,8 +828,9 @@ function deleteTarget(targetId) {
             method: 'POST',
             headers: {
                 'Content-Type': 'application/x-www-form-urlencoded',
+                'X-CSRF-Token': nonce
             },
-            body: `action=delete_target&target_id=${targetId}&nonce=<?php echo $_SESSION['nonce']; ?>`
+            body: `action=delete_target&target_id=${targetId}`
         })
         .then(response => response.json())
         .then(data => {
@@ -889,7 +900,7 @@ document.getElementById('scheduleForm').addEventListener('submit', function(e) {
     
     const formData = new FormData(this);
     formData.append('action', document.getElementById('scheduleId').value ? 'update_schedule' : 'create_schedule');
-    formData.append('nonce', '<?php echo $_SESSION['nonce']; ?>');
+    // CSRF token will be added via header
     
     fetch('api/backup-actions.php', {
         method: 'POST',
@@ -988,8 +999,9 @@ function testSchedule(scheduleId) {
             method: 'POST',
             headers: {
                 'Content-Type': 'application/x-www-form-urlencoded',
+                'X-CSRF-Token': nonce
             },
-            body: `action=test_schedule&schedule_id=${scheduleId}&nonce=<?php echo $_SESSION['nonce']; ?>`
+            body: `action=test_schedule&schedule_id=${scheduleId}`
         })
         .then(response => response.json())
         .then(data => {
@@ -1012,8 +1024,9 @@ function deleteSchedule(scheduleId) {
             method: 'POST',
             headers: {
                 'Content-Type': 'application/x-www-form-urlencoded',
+                'X-CSRF-Token': nonce
             },
-            body: `action=delete_schedule&schedule_id=${scheduleId}&nonce=<?php echo $_SESSION['nonce']; ?>`
+            body: `action=delete_schedule&schedule_id=${scheduleId}`
         })
         .then(response => response.json())
         .then(data => {
@@ -1054,8 +1067,9 @@ function runSchedulerNow() {
             method: 'POST',
             headers: {
                 'Content-Type': 'application/x-www-form-urlencoded',
+                'X-CSRF-Token': nonce
             },
-            body: `action=run_scheduler&nonce=<?php echo $_SESSION['nonce']; ?>`
+            body: `action=run_scheduler`
         })
         .then(response => response.json())
         .then(data => {
